==> mozc-1.3.931.102.tar.bz2: mozc-1.3.931.102/sync/contact_list_util.h <==
// Copyright 2010-2011, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_SYNC_CONTACT_LIST_UTIL_H_
#define MOZC_SYNC_CONTACT_LIST_UTIL_H_

#include "base/base.h"
#include "dictionary/user_dictionary_storage.pb.h"

namespace mozc {
namespace sync {

class ContactListUtil {
 public:
  // This function parses the |contact_update| as a json script and construct
  // a dictionary and stores a time stamp into |last_timestamp|.
  // |contact_update| script figures the differentials in the contact list
  // and the time stamp
  static bool ParseContacts(const string &contact_update,
      user_dictionary::UserDictionaryStorage::UserDictionary *user_dictionary,
      string *last_timestamp);

 private:
  DISALLOW_COPY_AND_ASSIGN(ContactListUtil);

};

}  //namespace sync
}  // namespace mozc
#endif  // MOZC_SYNC_CONTACT_LIST_UTIL_H_

==> mozc-1.6.1187.102.tar.bz2: mozc-1.6.1187.102/sync/contact_list_util.h <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_SYNC_CONTACT_LIST_UTIL_H_
#define MOZC_SYNC_CONTACT_LIST_UTIL_H_

#include "base/port.h"

namespace mozc {

namespace user_dictionary {
class UserDictionary;
}  // namespace user_dictionary

namespace sync {

class ContactListUtil {
 public:
  // This function parses the |contact_update| as a json script and construct
  // a dictionary and stores a time stamp into |last_timestamp|.
  // |contact_update| script figures the differentials in the contact list
  // and the time stamp
  static bool ParseContacts(
      const string &contact_update,
      user_dictionary::UserDictionary *user_dictionary,
      string *last_timestamp);

 private:
  DISALLOW_IMPLICIT_CONSTRUCTORS(ContactListUtil);
};

}  //namespace sync
}  // namespace mozc
#endif  // MOZC_SYNC_CONTACT_LIST_UTIL_H_
